# Repository for Fully Bayesian ComBat

This is the home of Fully Bayesian Combat, an extension of [Longitudinal ComBat](https://github.com/jcbeer/longCombat) which uses fully Bayesian inference rather than empirical Bayes.
